@@ -2,8 +2,8 @@
 function (MOD) 
 {
 b <- summary(MOD)$coef[-1,1]
-sx <- sd(MOD$model[-1])
-sy <- sd(MOD$model[1])
+sx <- sapply(MOD$model[-1], sd)
+sy <- sapply(MOD$model[1], sd)
 beta <- b * sx /  sy
 return(beta)
 }
